@echo off
::
:: TeamCall CA Innovaphone (Windows)
:: windows-installer.bat
::
:: Copyright (c) 2024-2025 by ilink Kommunikationssysteme GmbH.  All Rights Reserved.
::
:: Requirement: java.exe needs to be on the search path.
::


:: java executable used for running the IzPack installer
:: (needs to be on the search path)
set JAVA_BIN=java.exe


set DEBUGOPTIONS=-DSTACKTRACE=true
:: Use this for debugging:
::set DEBUGOPTIONS=-DTRACE=true -DSTACKTRACE=true

:: "%~dp0" expands to the folder of this batch file
set LOG_FILE=""%~dp0"\CAInnovaphone-install.log"



echo.
echo Starting CA Innovaphone Windows install script
echo. > "%LOG_FILE%"
echo Starting CA Innovaphone Windows install script >> "%LOG_FILE%"



:: Unlike bash, the Windows batch processor does not expand wildcards in arguments.
:: So we use the following to determine the exact name of the installer jar file:
for %%A in ("%~dp0"\ca_innovaphone_install*.jar) do (
    set INSTALLER=%%A
)


echo.
echo Starting CA Innovaphone installer
echo. >> "%LOG_FILE%"
echo Starting CA Innovaphone installer >> "%LOG_FILE%"

echo.
echo ^> "%JAVA_BIN%" %DEBUGOPTIONS% -jar "%INSTALLER%"
echo. >> "%LOG_FILE%"
echo ^> "%JAVA_BIN%" %DEBUGOPTIONS% -jar "%INSTALLER%" >> "%LOG_FILE%"

"%JAVA_BIN%" %DEBUGOPTIONS% -jar "%INSTALLER%" 2>&1 >> "%LOG_FILE%"
set RETVAL=%ERRORLEVEL%
if %RETVAL% NEQ 0 (
	echo "The installer failed (code %RETVAL%)."
	echo "Check log file %LOG_FILE% for details."
	echo "The installer failed (code %RETVAL%)." >> %LOG_FILE%
	goto Error
)



echo. >> "%LOG_FILE%"
echo. >> "%LOG_FILE%"
echo Installer warnings and errors: >> "%LOG_FILE%"
echo ---------------------------------------------------------------- >> "%LOG_FILE%"
type izpack.log >> "%LOG_FILE%"
echo ---------------------------------------------------------------- >> "%LOG_FILE%"

echo. >> "%LOG_FILE%"
echo. >> "%LOG_FILE%"
echo installFirstNode log: >> "%LOG_FILE%"
echo ---------------------------------------------------------------- >> "%LOG_FILE%"
type installFirstNode.log >> "%LOG_FILE%"
echo ---------------------------------------------------------------- >> "%LOG_FILE%"

echo. >> "%LOG_FILE%"
echo. >> "%LOG_FILE%"
echo registerService log: >> "%LOG_FILE%"
echo ---------------------------------------------------------------- >> "%LOG_FILE%"
type registerService.log >> "%LOG_FILE%"
echo ---------------------------------------------------------------- >> "%LOG_FILE%"
echo. >> "%LOG_FILE%"
echo. >> "%LOG_FILE%"



:: Remove consolidated logs (these have been written to $INSTALLLOGFILE above)
del izpack.log >nul 2>&1
del installFirstNode.log >nul 2>&1
del registerService.log >nul 2>&1


echo.
echo.
echo NOTE: The service has been installed and has been started
echo. >> "%LOG_FILE%"
echo. >> "%LOG_FILE%"
echo NOTE: The service has been installed and has been started >> "%LOG_FILE%"

goto ScriptEnd



rem ###########################################################################################################################
:Error

echo. >> "%LOG_FILE%"
echo ERROR! >> "%LOG_FILE%"



rem ###########################################################################################################################
:ScriptEnd

echo. >> "%LOG_FILE%"
echo. >> "%LOG_FILE%"


echo.
echo.
echo Generated installer log file:
echo %LOG_FILE%
echo.
